==> lxqt-panel-2.1.4-1.src.tar.gz: lxqt-panel-2.1.4/plugin-customcommand/translations/customcommand_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="188"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfiguracja własnej komendy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
        <source>Use icon from theme or browse file</source>
        <translation>Użyj ikony z motywu lub przeglądaj pliki</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uruchom przez „bash -c”</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Command</source>
        <translation>Komenda</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
        <source>Use %1 to display command output</source>
        <translation>Użyj % 1, aby wyświetlić wynik polecenia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatyczne obracanie, gdy panel jest ustawiony w pionie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
        <source>echo Configure...</source>
        <translation>echo Konfiguruj…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
        <source>Command to run</source>
        <translation>Komenda do uruchomienia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>Max Width</source>
        <translation>Maks. szerokość</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>Repeat command after:</source>
        <translation>Powtórz komendę po:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
        <source> second(s)</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
        <source>Command outputs an image</source>
        <translation>Polecenie wyświetla obraz</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Tooltip</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
        <source>Mouse Commands</source>
        <translation>Komendy myszy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
        <source>Wheel Up</source>
        <translation>Kółko w górę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
        <source>Wheel Down</source>
        <translation>Kółko w dół</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Select Icon File</source>
        <translation>Wybierz plik ikony</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Obrazy (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-customcommand/translations/customcommand_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Kliknij, aby zmienić kolor</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Wybierz kolor</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="197"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfiguracja własnej komendy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use icon from theme or browse file</source>
        <translation>Użyj ikony z motywu lub przeglądaj pliki</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uruchom przez „bash -c”</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
        <source>Command</source>
        <translation>Komenda</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source>Use %1 to display command output</source>
        <translation>Użyj % 1, aby wyświetlić wynik polecenia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatyczne obracanie, gdy panel jest ustawiony w pionie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
        <source>echo Configure...</source>
        <translation>echo Konfiguruj…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
        <source>Command to run</source>
        <translation>Komenda do uruchomienia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
        <source>Max Width</source>
        <translation>Maks. szerokość</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
        <source>Repeat command after:</source>
        <translation>Powtórz komendę po:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Text Color</source>
        <translation>Kolor tekstu</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
        <source>Reset</source>
        <translation>Zresetuj</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
        <source> second(s)</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
        <source>Command outputs an image</source>
        <translation>Polecenie wyświetla obraz</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source>Tooltip</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Mouse Commands</source>
        <translation>Komendy myszy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
        <source>Wheel Up</source>
        <translation>Kółko w górę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
        <source>Wheel Down</source>
        <translation>Kółko w dół</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Select Icon File</source>
        <translation>Wybierz plik ikony</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Obrazy (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
